@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '1.12'
-Build = '5'
+Build = '6'
 
 import sys
 import os
@@ -119,6 +119,9 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        
        # print driverStateInjection, interfaceStateMonitor
 
+       ##Clean the interface
+       self.ui.scanList.clear()
+       self.ui.textBrowser.clear()
        ##Check first if the correct drivers are loaded and the interface is in monitor mode
        if driverStateInjection == 'False' or interfaceStateMonitor == 'False':
           message ='ERROR: Cannot scan for available networks.\n\nThe drivers or the interface are not to the correct state.\nPlease configure them from the available menu option.'
@@ -130,9 +133,11 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           showQuickMessage(message) 
           
           os.system('sudo %s/%s getWlanInformation %s %s' % (pathMain, helperScript, pathTemp, duration))
-          message ='Scan for available networks completed!'
+          message ='Scan for available networks completed!\nChoose WEP or WPA..'
           showQuickMessage(message)
 
+       self.ui.textBrowser.append(message)
+
     def displayNetworks(self): #FIXME: read ESSIDs directly and not from the file.
        '''Show available networks in the UI.'''
 
@@ -168,7 +173,7 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
 
     def displayNetworkInformation(self): #FIXME: read wlan info directly and not from a file.
 
-       global essid, bssid, channel, encryption
+       global essid, bssid, channel, encryption, essid_clean
     
        if self.ui.scanList.currentRow() == -1:
           self.ui.textBrowser.clear()
@@ -176,13 +181,13 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           return
        self.ui.captureButton.setEnabled(True)
        essid = self.ui.scanList.currentItem().text()
-       essidInfo = os.popen('sudo %s/%s readESSIDinfo %s %s' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
+       essidInfo = os.popen('sudo %s/%s readESSIDinfo %s \"%s\"' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
        
        essid = essidInfo[0]
        bssid = essidInfo[1]
        channel = essidInfo[2]
        encryption = essidInfo[3]
-       essid = essid.strip()
+       essid = essid.lstrip(" ").rstrip(" ")
        bssid = bssid.strip()
        channel = channel.strip()
        encryption = encryption.strip()
@@ -191,6 +196,14 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        self.ui.textBrowser.append('Name: ' + essid)
        self.ui.textBrowser.append('MAC: ' + bssid)
        self.ui.textBrowser.append('Ch: ' + channel + ' Security: ' + encryption)
+  
+  
+       essid_clean = essid
+       character_list = [' ', '(', ')', '!', '$', '%', '^', '&', '*', '-', '+', '=', '#', '@', ';', ':', '?', '/', '>', '<'] 
+       for i in character_list:
+          essid_clean = essid_clean.replace(i,'_')
+       print 'essid (clean): ', essid_clean   
+       
     def executeCapture(self):
        '''Opens an xterm window that captures the packets.'''
    
@@ -222,12 +235,13 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
 
           self.ui.authenticateButton.setEnabled(False)
           self.ui.injectionButton.setEnabled(False)
-          # self.ui.deauthenticateButton.setEnabled(True) ##INFO: uncomment when "executeDeauthenticate" is fixed.
+          self.ui.deauthenticateButton.setEnabled(True)
           
-       # print "capture options: ", channel, bssid, pathTemp, encryption, essid
-       os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s %s" &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
+       # print "capture options: ", channel, bssid, pathTemp, encryption, essid, essid_clean
+       # os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s \"%s\" " &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
+       os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s \"%s\" " &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid_clean))
       
-    def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac
+    def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac; atm ignoring essid and just broadcasting. 
        '''Opens an xterm window that sends deauthentication packets.'''
        
        # print "deauthenticate options: ", bssid, essid
@@ -291,7 +305,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        elif kernelVersion == '2.6.28.10-power49':
           pass
        else: 
-          message = 'WARNING: The system did not find a compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
+          message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
           showMessage(message)
     
     def getDriversState(self):
@@ -373,10 +387,10 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        '''Get the MAC address defined on the device'''
 
        if self.ui.enableMonitor.isEnabled():
-          #interface is in Managed mode
+          ##interface is in Managed mode
           macList = os.popen('sudo %s/%s getMACmanaged' %(pathMain, helperScript)).read()
        else:
-          #interface is in Monitor mode 
+          ##interface is in Monitor mode 
           macList = os.popen('sudo %s/%s getMACmonitor' %(pathMain, helperScript)).read()
        
        myMAC = macList[0:17]
@@ -421,7 +435,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
     def setConnectionBehaviour(self):
        '''Set new data connection behaviour.'''
 
-       ## Available options: [WLAN_INFRA], [GPRS], [*] <=='any', [] <=='ask'
+       ##Available options: [WLAN_INFRA], [GPRS], [*] <=='any', [] <=='ask'
        if self.ui.ASK.isChecked():
            String = ''
        elif self.ui.WLAN.isChecked():
@@ -431,7 +445,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        elif self.ui.ANY.isChecked():
            String = '*'
           
-       ## Set requested setting for "Connect automatically" 
+       ##Set user requested value for the "Connect automatically" option 
        os.system('gconftool-2 -s --type list --list-type string /system/osso/connectivity/network_type/auto_connect [%s]' % String)
 
 class clevenSelectDictionary(QtGui.QDialog): # Complete
@@ -470,7 +484,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        QtCore.QObject.connect(self.ui.actionEnableDeleteOptions, QtCore.SIGNAL('triggered()'), self.enableDeleteOptions)
        QtCore.QObject.connect(self.ui.actionDisableDeleteOptions, QtCore.SIGNAL('triggered()'), self.disableDeleteOptions)
        
-       # Decryption
+       ##Decryption and Deletion actions
        QtCore.QObject.connect(self.ui.decryptButton, QtCore.SIGNAL('clicked()'), self.decryptORdeleteCapturedFiles)
        QtCore.QObject.connect(self.ui.dictionaryButton, QtCore.SIGNAL('clicked()'), self.showSelectDictionaryDialog)
        QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableDecryptionButtons)
@@ -508,13 +522,19 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        
        global deleteModeOn
        deleteModeOn = 'True'
+
+       self.setWindowTitle('Deletion')
        
        self.ui.decryptButton.setEnabled(False)
        self.ui.decryptButton.setText('Delete')       
        self.ui.selectCommonRadio.setEnabled(False)
        self.ui.actionEnableDeleteOptions.setEnabled(False)
        self.ui.actionDisableDeleteOptions.setEnabled(True)
-       self.setWindowTitle('Deletion')
+       
+       ##Hide the dictionary selection buttons 
+       self.ui.dictionaryButton.setHidden(True)
+       self.ui.dictionaryLine.setHidden(True)
+
        
     def disableDeleteOptions(self):
        '''Disable in the UI the Delete buttons'''
@@ -600,7 +620,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
              name = self.capfile.strip().rpartition('-')
              cap = name[0]
           else:
-             cap = self.capfile.strip().replace('.cap','')
+             cap = self.capfile.strip().replace('.cap','').replace('.ivs','')
           print "delete cap: ", cap
 
           os.system('sudo %s/%s deleteCaptured %s %s %s' % (pathMain, helperScript, pathTemp, encryption, cap))
@@ -661,7 +681,7 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        aboutScrollArea = QScrollArea(self)
        aboutScrollArea.setWidgetResizable(True)
        awidget = QWidget(aboutScrollArea)
-       #awidget.setMinimumSize(470,1480)
+       # awidget.setMinimumSize(470,1480)
        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        try:
@@ -674,8 +694,9 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        
        aboutIcon = QLabel()
        aboutIcon.setPixmap( QIcon.fromTheme('cleven').pixmap(128,128) )
-       aboutIcon.resize(128,128)
        aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+       aboutIcon.resize(128,128)
+
        aboutLayout.addWidget(aboutIcon)
        
        aboutLabel = QLabel('''<center><b>Cleven</b><br>version: %s 
@@ -685,7 +706,7 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        <br><br>It provides the ability to easily configure the injection drivers, scan for surrounding stations, and by using injection and authentication or deauthentication, capture Identification Vector keys. 
        <br><br>In addition, it provides interfaces to decrypt the captured files and manage the keys from successful attacks. 
        <br><br><b>DISCLAIMER:</b> 
-       <br>This program is intended for learning purposes only. I do not condone hacking and would not be held responsible for your actions. Only you would face legal consequences if you used this script for illegal activities. 
+       <br>This program is intended for learning purposes only. I do not condone hacking and would not be held responsible for your actions. Only you would face legal consequences if you used this application for illegal activities. 
        <br><br>Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end). 
        <br><br><b>THANKS TO:</b> 
        <br><br><b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by sending him your donations. See for more info: http://david.gnedt.eu/blog/wl1251/ 
